@@ -245,7 +245,7 @@ class Tado:
         data = self._apiCall(cmd, "DELETE", {}, True)
         return data
 
-    def setZoneOverlay(self, zone, overlayMode, setTemp=None, duration=None):
+    def setZoneOverlay(self, zone, overlayMode, setTemp=None, duration=None, deviceType='HEATING', power="ON", mode=None):
         """set current overlay for a zone"""
         # pylint: disable=C0103
 
@@ -258,13 +258,22 @@ class Tado:
 
         if setTemp is None:
             post_data["setting"] = {
-                "type":"HEATING",
-                "power":"OFF"
+                "type": deviceType,
+                "power": power
+            }
+        elif mode is not None:
+            post_data["setting"] = {
+                "type": deviceType,
+                "power": power,
+                "mode": mode,
+                "temperature":{
+                    "celsius": setTemp
+                }
             }
         else:
             post_data["setting"] = {
-                "type":"HEATING",
-                "power":"ON",
+                "type": deviceType,
+                "power": power,
                 "temperature":{
                     "celsius": setTemp
                 }
